function noop() { }

var EventEmitter = /** @class */ (function () {
    function EventEmitter() {
        this.events = [];
    }
    EventEmitter.prototype.on = function (eventName, listener, context) {
        if (listener === void 0) { listener = noop; }
        this.events.push({ eventName: eventName, listener: listener, context: context });
        return this;
    };
    EventEmitter.prototype.off = function (eventName, listener) {
        var matched = this.events.findIndex(function (regEvent) { return regEvent.eventName === eventName && (listener ? regEvent.listener === listener : true); });
        if (!~matched) {
            return;
        }
        this.events.splice(matched, 1);
        return this;
    };
    EventEmitter.prototype.once = function (eventName, listener, context) {
        var _this = this;
        if (listener === void 0) { listener = noop; }
        var onceWrapper = function () {
            var values = [];
            for (var _i = 0; _i < arguments.length; _i++) {
                values[_i] = arguments[_i];
            }
            _this.off(eventName, onceWrapper);
            listener.apply(context || listener, values);
        };
        this.on(eventName, onceWrapper, context);
        return this;
    };
    EventEmitter.prototype.emit = function (eventName) {
        var values = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            values[_i - 1] = arguments[_i];
        }
        this.events.forEach(function (regEvent) {
            if (regEvent.eventName === eventName) {
                regEvent.listener.apply(regEvent.context || regEvent.listener, values);
            }
        });
        return this;
    };
    EventEmitter.prototype.fire = function (eventName) {
        var values = [];
        for (var _i = 1; _i < arguments.length; _i++) {
            values[_i - 1] = arguments[_i];
        }
        this.emit(eventName, values);
        return this;
    };
    return EventEmitter;
}());

/*
 * Public API Surface of @nonoll/code-snippet/event
 */

/**
 * Generated bundle index. Do not edit.
 */

export { EventEmitter };
//# sourceMappingURL=nonoll-code-snippet-event.js.map
